/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem;

import java.util.Map;

import com.ibm.ram.common.data.*;
import com.ibm.ram.internal.client.util.AssetConstants;


/**
 * 
 * @author ebordeau
 * @since 7.1
 */
public class CategoryRule extends AbstractRule {

	static final String SCHEMA_NAME = "schemaName"; //$NON-NLS-1$
	static final String CATEGORY_NAME = "categoryName"; //$NON-NLS-1$
	static final String SUBCATEGORIES = "subcategories"; //$NON-NLS-1$
	public static final String ID = CategoryRule.class.getName();
	
	private String schemaName;
	private String categoryName;
	private String subCategories;
	
	public void initialize(Map config) {
		super.initialize(config);
		setSchemaName((String)config.get(SCHEMA_NAME));
		setCategoryName((String)config.get(CATEGORY_NAME));
		setSubCategories((String)config.get(SUBCATEGORIES));
	}

	public void save(Map config) {
		super.save(config);
		config.put(SCHEMA_NAME, schemaName);
		config.put(CATEGORY_NAME, categoryName);
		config.put(SUBCATEGORIES, subCategories);
	}
	
	public boolean applyValue(Asset asset) {
		if (isValid()) {
			addSubCategory(asset);
			return true;
		}
		return false;
	}
	
	private boolean isValid() {
		return schemaName != null && schemaName.length() > 0 
			&& categoryName != null && categoryName.length() > 0 
			&& subCategories != null && subCategories.length() > 0;
	}
	
	private SubCategory addSubCategory(Asset asset) {
		String[] subCategories = this.subCategories.split(AssetConstants.FILE_DELIM);
		Category category = addCategory(asset, schemaName, categoryName);
		SubCategory subCategory = null;
		StringBuffer fullPath = new StringBuffer(schemaName + AssetConstants.FILE_DELIM + categoryName);
		for (int i = 0; i < subCategories.length; i++) {
			fullPath.append(AssetConstants.FILE_DELIM + subCategories[i]);
			SubCategory parent = subCategory;
			SubCategory[] oldSubCategories = null;
			if (parent != null) {
				subCategory = parent.getSubCategory(subCategories[i]);
				oldSubCategories = parent.getSubCategories();
			} else {
				subCategory = category.getSubCategory(subCategories[i]);
				oldSubCategories = category.getSubCategories();
			}
			if (subCategory == null) {
				if (oldSubCategories == null)
					oldSubCategories = new SubCategory[0];
				SubCategory[] newSubCategories = new SubCategory[oldSubCategories.length + 1];
				System.arraycopy(oldSubCategories, 0, newSubCategories, 0, oldSubCategories.length);
				subCategory = new SubCategory();
				subCategory.setName(subCategories[i]);
				subCategory.setFullPath(fullPath.toString());
				newSubCategories[newSubCategories.length - 1] = subCategory;
				if (parent != null)
					parent.setSubCategories(newSubCategories);
				else
					category.setSubCategories(newSubCategories);
			}
		}
		if (subCategory != null)
			subCategory.setSet(true);
		return subCategory;
	}
	
	private Category addCategory(Asset asset, String schemaName, String categoryName) {
		CategorySchema schema = addCategorySchema(asset, schemaName);
		Category category = schema.getCategory(categoryName);
		if (category == null) {
			Category[] oldCategories = schema.getCategories();
			if (oldCategories == null) 
				oldCategories = new Category[0];
			Category[] newCategories = new Category[oldCategories.length + 1];
			System.arraycopy(oldCategories, 0, newCategories, 0, oldCategories.length);
			category = new Category();
			category.setName(categoryName);
			newCategories[newCategories.length - 1] = category;
			schema.setCategories(newCategories);
		}
		return category;
	}
	
	private CategorySchema addCategorySchema(Asset asset, String schemaName) {
		CategorySchema schema = asset.getCategorySchema(schemaName);
		if (schema == null) {
			CategorySchema[] oldSchemas = asset.getCategorySchemas();
			if (oldSchemas == null)
				oldSchemas = new CategorySchema[0];
			CategorySchema[] newSchemas = new CategorySchema[oldSchemas.length + 1];
			System.arraycopy(oldSchemas, 0, newSchemas, 0, oldSchemas.length);
			schema = new CategorySchema();
			schema.setName(schemaName);
			newSchemas[newSchemas.length - 1] = schema;
			asset.setCategorySchemas(newSchemas);
		}
		return schema;
	}
	
	public String getId() {
		return ID;
	}
	
	public void setCategoryName(String categoryName) {
		this.categoryName = categoryName;
	}
	
	public void setSchemaName(String schemaName) {
		this.schemaName = schemaName;
	}
	
	public void setSubCategories(String subCategories) {
		this.subCategories = subCategories;
	}

}
