/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem;

import java.util.Map;

import com.ibm.ram.common.data.Asset;
import com.ibm.ram.common.data.CommunityInformation;

/**
 * Creates a community from a file system object.
 * 
 * @author ebordeau
 * @since 7.1
 */
public class CommunityRule extends AbstractRuleContainer {
	
	static final String COMMUNITY_NAME_KEY = "community"; //$NON-NLS-1$
	public static final String ID = CommunityRule.class.getName();
	
	private String communityName;
	
	public boolean applyValue(Asset asset) {
		if (communityName != null && communityName.length() > 0) {
			CommunityInformation community = new CommunityInformation();
			community.setName(communityName);
			asset.setCommunity(community);
			return true;
		}
		return false;
	}
	
	public void initialize(Map config) {
		super.initialize(config);
		setCommunityName((String)config.get(COMMUNITY_NAME_KEY));
	}

	public void save(Map config) {
		super.save(config);
		config.put(COMMUNITY_NAME_KEY, communityName);
	}
	
	public String getId() {
		return ID;
	}
	
	public void setCommunityName(String name) {
		this.communityName = name;
	}

}
