/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem.ui;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.*;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.*;
import org.eclipse.ui.PlatformUI;

import com.ibm.ram.internal.batch.filesystem.*;
import com.ibm.ram.internal.rich.ui.util.HelpIds;
import com.ibm.ram.internal.rich.ui.util.Messages;

/**
 * Specify the metadata for an artifact rule.
 * 
 * @author ebordeau
 * @since 7.1
 */
public class ArtifactRulePage extends RuleWizardPage {
	
	private ArtifactRule rule;
	
	private Button allObjectsButton;
	private Button filteredObjectsButton;
	private Button staticValueButton;
	
	private Text filterText;
	private Text labelText;
	private Text nameText;
	private Text urlText;
	
	/**
	 * @param pageName
	 * @param title
	 * @param titleImage
	 */
	public ArtifactRulePage(IRuleContainer ruleContainer) {
		super(ruleContainer, ArtifactRule.ID, Messages.Batch_FileSystem_Rule_ArtifactWizardPage_Title, null);
		setMessage(Messages.Batch_FileSystem_Rule_WizardPage_Description);
	}

	public void createControl(Composite parent) {
		Composite composite = new Composite(parent, SWT.NONE);
		composite.setLayout(new GridLayout());
		composite.setLayoutData(new GridData(GridData.FILL_BOTH));
		
		allObjectsButton = new Button(composite, SWT.RADIO);
		allObjectsButton.setLayoutData(new GridData());
		allObjectsButton.setText(Messages.Batch_FileSystem_Rule_ArtifactWizardPage_AllFilesButtonLabel);
		allObjectsButton.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		allObjectsButton.setSelection(true);
		
		filteredObjectsButton = new Button(composite, SWT.RADIO);
		filteredObjectsButton.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		filteredObjectsButton.setText(Messages.Batch_FileSystem_Rule_ArtifactWizardPage_FilteredFilesButtonLabel);

		Composite filterComposite = new Composite(composite, SWT.NONE);
		filterComposite.setLayout(new GridLayout(2, false));
		filterComposite.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		
		final Label filterLabel = new Label(filterComposite, SWT.NONE);
		filterLabel.setText(Messages.Batch_FileSystem_Rule_Filter + ":"); //$NON-NLS-1$
		filterLabel.setLayoutData(new GridData());
		filterLabel.setEnabled(false);
		
		filterText = new Text(filterComposite, SWT.BORDER);
		filterText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		filterText.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent event) {
				Text text = (Text)event.widget;
				getRule().setFilter(text.getText());
				setPageComplete(canFinish());
			}
		});
		filterText.setEnabled(false);

		final Label labelLabel = new Label(filterComposite, SWT.NONE);
		labelLabel.setText(Messages.ASSET_CONTENT_PAGE_CONTENT_SECTION_LABEL_FIELD + ":"); //$NON-NLS-1$
		labelLabel.setLayoutData(new GridData());
		labelLabel.setEnabled(false);
		
		labelText = new Text(filterComposite, SWT.BORDER);
		labelText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		labelText.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent event) {
				Text text = (Text)event.widget;
				getArtifactRule().setArtifactLabel(text.getText());
				setPageComplete(canFinish());
			}
		});
		labelText.setEnabled(false);
		
		filteredObjectsButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent event) {
				filterLabel.setEnabled(filteredObjectsButton.getSelection());
				filterText.setEnabled(filteredObjectsButton.getSelection());
				labelLabel.setEnabled(filteredObjectsButton.getSelection());
				labelText.setEnabled(filteredObjectsButton.getSelection());
				setPageComplete(canFinish());
			}
		});
		
		staticValueButton = new Button(composite, SWT.RADIO);
		staticValueButton.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		staticValueButton.setText(Messages.Batch_FileSystem_Rule_ArtifactWizardPage_StaticButtonLabel);
		
		Composite staticComposite = new Composite(composite, SWT.NONE);
		staticComposite.setLayout(new GridLayout(2, false));
		staticComposite.setLayoutData(new GridData(GridData.FILL_BOTH));
		
		final Label nameLabel = new Label(staticComposite, SWT.NONE);
		nameLabel.setText(Messages.Batch_FileSystem_Rule_Name + ":"); //$NON-NLS-1$
		nameLabel.setLayoutData(new GridData());
		nameLabel.setEnabled(false);
		
		nameText = new Text(staticComposite, SWT.BORDER);
		nameText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		nameText.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent event) {
				Text text = (Text)event.widget;
				getArtifactRule().setArtifactName(text.getText());
				setPageComplete(canFinish());
			}
		});
		nameText.setEnabled(false);

		final Label urlLabel = new Label(staticComposite, SWT.NONE);
		urlLabel.setText(Messages.Batch_FileSystem_Rule_URL + ":"); //$NON-NLS-1$
		urlLabel.setLayoutData(new GridData());
		urlLabel.setEnabled(false);
		
		urlText = new Text(staticComposite, SWT.BORDER);
		urlText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		urlText.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent event) {
				Text text = (Text)event.widget;
				getArtifactRule().setArtifactUrl(text.getText());
				setPageComplete(canFinish());
			}
		});
		urlText.setEnabled(false);

		staticValueButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent event) {
				nameLabel.setEnabled(staticValueButton.getSelection());
				nameText.setEnabled(staticValueButton.getSelection());
				urlLabel.setEnabled(staticValueButton.getSelection());
				urlText.setEnabled(staticValueButton.getSelection());
			}
		});

		setControl(composite);
		setPageComplete(canFinish());
		PlatformUI.getWorkbench().getHelpSystem().setHelp(composite, HelpIds.RULEPAGE_ARTIFACT);
	}
	
	protected ArtifactRule getArtifactRule() {
		return (ArtifactRule)getRule();
	}
	
	public IRule getRule() {
		if (rule == null)
			rule = new ArtifactRule();
		return rule;
	}
	
	private boolean canFinish() {
		if (filteredObjectsButton != null && filteredObjectsButton.getSelection())
			return filterText.getText().length() > 0;
		if (staticValueButton != null && staticValueButton.getSelection())
			return nameText.getText().length() > 0 && urlText.getText().length() > 0;
		return true;
	}
	
}
