/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem.ui;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.*;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.*;
import org.eclipse.ui.PlatformUI;

import com.ibm.ram.internal.batch.filesystem.*;
import com.ibm.ram.internal.rich.ui.util.HelpIds;
import com.ibm.ram.internal.rich.ui.util.Messages;

/**
 * Specify the metadata for an artifact rule.
 * 
 * @author ebordeau
 * @since 7.1
 */
public class AttributeRulePage extends RuleWizardPage {
	
	private AttributeRule rule;
	private Button filteredObjectsButton;
	private Button staticValueButton;
	private Text filterText;
	private Text attNameText;
	private Text attValueText;
	
	/**
	 * @param pageName
	 * @param title
	 * @param titleImage
	 */
	public AttributeRulePage(IRuleContainer ruleContainer) {
		super(ruleContainer, AttributeRule.ID, Messages.Batch_FileSystem_Rule_AttributeWizardPage_Title, null);
		setMessage(Messages.Batch_FileSystem_Rule_WizardPage_Description);
	}

	public void createControl(Composite parent) {
		Composite composite = new Composite(parent, SWT.NONE);
		composite.setLayout(new GridLayout());
		composite.setLayoutData(new GridData(GridData.FILL_BOTH));
		
		filteredObjectsButton = new Button(composite, SWT.RADIO);
		filteredObjectsButton.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		filteredObjectsButton.setText(Messages.Batch_FileSystem_AttributeRuleWizardPage_FilteredFilesButtonText);
		filteredObjectsButton.setSelection(true);
		
		Composite filterComposite = new Composite(composite, SWT.NONE);
		filterComposite.setLayout(new GridLayout(2, false));
		filterComposite.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		
		final Label filterLabel = new Label(filterComposite, SWT.NONE);
		filterLabel.setText(Messages.Batch_FileSystem_Rule_Filter + ":"); //$NON-NLS-1$
		filterLabel.setLayoutData(new GridData());
		filterLabel.setEnabled(true);
		
		filterText = new Text(filterComposite, SWT.BORDER);
		filterText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		filterText.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent event) {
				Text text = (Text)event.widget;
				getRule().setFilter(text.getText());
				setPageComplete(canFinish());
			}
		});
		filterText.setEnabled(true);
		filteredObjectsButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent event) {
				filterLabel.setEnabled(filteredObjectsButton.getSelection());
				filterText.setEnabled(filteredObjectsButton.getSelection());
				setPageComplete(canFinish());
			}
		});
		
		staticValueButton = new Button(composite, SWT.RADIO);
		staticValueButton.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		staticValueButton.setText(Messages.Batch_FileSystem_Rule_AttributeWizardPage_StaticButtonLabel);
		
		Composite staticComposite = new Composite(composite, SWT.NONE);
		staticComposite.setLayout(new GridLayout(2, false));
		staticComposite.setLayoutData(new GridData(GridData.FILL_BOTH));
		
		final Label attNameLabel = new Label(staticComposite, SWT.NONE);
		attNameLabel.setText(Messages.Batch_FileSystem_Rule_AttributeName + ":"); //$NON-NLS-1$
		attNameLabel.setLayoutData(new GridData());
		attNameLabel.setEnabled(false);
		
		attNameText = new Text(staticComposite, SWT.BORDER);
		attNameText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		attNameText.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent event) {
				Text text = (Text)event.widget;
				getAttributeRule().setAttributeName(text.getText());
				setPageComplete(canFinish());
			}
		});
		attNameText.setEnabled(false);

		final Label attValueLabel = new Label(staticComposite, SWT.NONE);
		attValueLabel.setText(Messages.Batch_FileSystem_Rule_AttributeValue + ":"); //$NON-NLS-1$
		attValueLabel.setLayoutData(new GridData());
		attValueLabel.setEnabled(false);
		
		attValueText = new Text(staticComposite, SWT.BORDER);
		attValueText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		attValueText.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent event) {
				Text text = (Text)event.widget;
				getAttributeRule().setAttributeValue(text.getText());
				setPageComplete(canFinish());
			}
		});
		attValueText.setEnabled(false);

		staticValueButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent event) {
				attNameLabel.setEnabled(staticValueButton.getSelection());
				attNameText.setEnabled(staticValueButton.getSelection());
				attValueLabel.setEnabled(staticValueButton.getSelection());
				attValueText.setEnabled(staticValueButton.getSelection());
				setPageComplete(canFinish());
			}
		});

		setControl(composite);
		setPageComplete(canFinish());
		PlatformUI.getWorkbench().getHelpSystem().setHelp(composite, HelpIds.RULEPAGE_ATTRIBUTE);
	}
	
	protected AttributeRule getAttributeRule() {
		return (AttributeRule)getRule();
	}
	
	public IRule getRule() {
		if (rule == null)
			rule = new AttributeRule();
		return rule;
	}
	
	private boolean canFinish() {
		if (filteredObjectsButton != null && filteredObjectsButton.getSelection())
			return filterText.getText().length() > 0;
		if (staticValueButton != null && staticValueButton.getSelection())
			return attNameText.getText().length() > 0 && attValueText.getText().length() > 0;
		return true;
	}
	
}
