/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem.ui;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.*;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.*;
import org.eclipse.ui.PlatformUI;

import com.ibm.ram.internal.batch.filesystem.*;
import com.ibm.ram.internal.rich.ui.util.HelpIds;
import com.ibm.ram.internal.rich.ui.util.Messages;

/**
 * Specify the metadata for an artifact rule.
 * 
 * @author ebordeau
 * @since 7.1
 */
public class CategoryRulePage extends RuleWizardPage {
	
	private CategoryRule rule;
	private Button filteredObjectsButton;
	private Button staticValueButton;
	private Text filterText;
	private Text schemaText;
	private Text categoryText;
	private Text subCategoryText;
	
	/**
	 * @param pageName
	 * @param title
	 * @param titleImage
	 */
	public CategoryRulePage(IRuleContainer ruleContainer) {
		super(ruleContainer, CategoryRule.ID, Messages.Batch_FileSystem_Rule_CategoryWizardPage_Title, null);
		setMessage(Messages.Batch_FileSystem_Rule_WizardPage_Description);
	}

	public void createControl(Composite parent) {
		Composite composite = new Composite(parent, SWT.NONE);
		composite.setLayout(new GridLayout());
		composite.setLayoutData(new GridData(GridData.FILL_BOTH));
		
		filteredObjectsButton = new Button(composite, SWT.RADIO);
		filteredObjectsButton.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		filteredObjectsButton.setText(Messages.Batch_FileSystem_CategoryRuleWizardPage_FilteredFilesButtonText);
		filteredObjectsButton.setSelection(true);

		Composite filterComposite = new Composite(composite, SWT.NONE);
		filterComposite.setLayout(new GridLayout(2, false));
		filterComposite.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		
		final Label filterLabel = new Label(filterComposite, SWT.NONE);
		filterLabel.setText(Messages.Batch_FileSystem_Rule_Filter + ":"); //$NON-NLS-1$
		filterLabel.setLayoutData(new GridData());
		filterLabel.setEnabled(true);
		
		filterText = new Text(filterComposite, SWT.BORDER);
		filterText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		filterText.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent event) {
				Text text = (Text)event.widget;
				getRule().setFilter(text.getText());
				setPageComplete(canFinish());
			}
		});
		filterText.setEnabled(true);
		filteredObjectsButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent event) {
				filterLabel.setEnabled(filteredObjectsButton.getSelection());
				filterText.setEnabled(filteredObjectsButton.getSelection());
				setPageComplete(canFinish());
			}
		});
		
		staticValueButton = new Button(composite, SWT.RADIO);
		staticValueButton.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		staticValueButton.setText(Messages.Batch_FileSystem_Rule_CategoryWizardPage_StaticButtonLabel);
		
		Composite staticComposite = new Composite(composite, SWT.NONE);
		staticComposite.setLayout(new GridLayout(2, false));
		staticComposite.setLayoutData(new GridData(GridData.FILL_BOTH));
		
		final Label schemaLabel = new Label(staticComposite, SWT.NONE);
		schemaLabel.setText(Messages.Batch_FileSystem_Rule_Schema + ":"); //$NON-NLS-1$
		schemaLabel.setLayoutData(new GridData());
		schemaLabel.setEnabled(false);
		
		schemaText = new Text(staticComposite, SWT.BORDER);
		schemaText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		schemaText.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent event) {
				Text text = (Text)event.widget;
				getCategoryRule().setSchemaName(text.getText());
				setPageComplete(canFinish());
			}
		});
		schemaText.setEnabled(false);

		final Label categoryLabel = new Label(staticComposite, SWT.NONE);
		categoryLabel.setText(Messages.Batch_FileSystem_Rule_Category + ":"); //$NON-NLS-1$
		categoryLabel.setLayoutData(new GridData());
		categoryLabel.setEnabled(false);
		
		categoryText = new Text(staticComposite, SWT.BORDER);
		categoryText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		categoryText.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent event) {
				Text text = (Text)event.widget;
				getCategoryRule().setCategoryName(text.getText());
				setPageComplete(canFinish());
			}
		});
		categoryText.setEnabled(false);

		final Label subCategoryLabel = new Label(staticComposite, SWT.NONE);
		subCategoryLabel.setText(Messages.Batch_FileSystem_Rule_Subcategories + ":"); //$NON-NLS-1$
		subCategoryLabel.setLayoutData(new GridData());
		subCategoryLabel.setEnabled(false);
		
		subCategoryText = new Text(staticComposite, SWT.BORDER);
		subCategoryText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		subCategoryText.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent event) {
				Text text = (Text)event.widget;
				getCategoryRule().setSubCategories(text.getText());
				setPageComplete(canFinish());
			}
		});
		subCategoryText.setEnabled(false);

		staticValueButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent event) {
				schemaLabel.setEnabled(staticValueButton.getSelection());
				schemaText.setEnabled(staticValueButton.getSelection());
				categoryLabel.setEnabled(staticValueButton.getSelection());
				categoryText.setEnabled(staticValueButton.getSelection());
				subCategoryLabel.setEnabled(staticValueButton.getSelection());
				subCategoryText.setEnabled(staticValueButton.getSelection());
				setPageComplete(canFinish());
			}
		});

		setControl(composite);
		setPageComplete(canFinish());
		PlatformUI.getWorkbench().getHelpSystem().setHelp(composite, HelpIds.RULEPAGE_CATEGORY);
	}
	
	protected CategoryRule getCategoryRule() {
		return (CategoryRule)getRule();
	}
	
	public IRule getRule() {
		if (rule == null)
			rule = new CategoryRule();
		return rule;
	}
	
	private boolean canFinish() {
		if (filteredObjectsButton != null && filteredObjectsButton.getSelection())
			return filterText.getText().length() > 0;
		if (staticValueButton != null && staticValueButton.getSelection())
			return subCategoryText.getText().length() > 0 && categoryText.getText().length() > 0 && schemaText.getText().length() > 0;
		return true;
	}
	
}
