/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem.ui;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.*;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.*;
import org.eclipse.ui.PlatformUI;

import com.ibm.ram.internal.batch.filesystem.*;
import com.ibm.ram.internal.rich.ui.util.HelpIds;
import com.ibm.ram.internal.rich.ui.util.Messages;

/**
 * Specify the metadata for an artifact rule.
 * 
 * @author ebordeau
 * @since 7.1
 */
public class CommunityRulePage extends RuleWizardPage {
	
	private CommunityRule rule;
	private Button filteredObjectsButton;
	private Button staticValueButton;
	private Text filterText;
	private Text communityNameText;
	
	/**
	 * @param pageName
	 * @param title
	 * @param titleImage
	 */
	public CommunityRulePage(IRuleContainer ruleContainer) {
		super(ruleContainer, CommunityRule.ID, Messages.Batch_FileSystem_Rule_CommunityWizardPage_Title, null);
		setMessage(Messages.Batch_FileSystem_Rule_WizardPage_Description);
	}

	public void createControl(Composite parent) {
		Composite composite = new Composite(parent, SWT.NONE);
		composite.setLayout(new GridLayout());
		composite.setLayoutData(new GridData(GridData.FILL_BOTH));
		
		String filteredButtonLabelText = Messages.Batch_FileSystem_CommunityRuleWizardPage_FilteredFileButtonText;
		boolean filteredButtonSelected = true;
		if (getRuleContainer() instanceof FileSystemDataSource) {
			Button allObjectsButton = new Button(composite, SWT.RADIO);
			allObjectsButton.setLayoutData(new GridData());
			allObjectsButton.setText(Messages.Batch_FileSystem_CommunityRuleWizardPage_AllFilesButtonText);
			allObjectsButton.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
			allObjectsButton.setSelection(true);
			filteredButtonLabelText = Messages.Batch_FileSystem_CommunityRuleWizardPage_FilteredFilesButtonText;
			filteredButtonSelected = false;
		}
		
		filteredObjectsButton = new Button(composite, SWT.RADIO);
		filteredObjectsButton.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		filteredObjectsButton.setText(filteredButtonLabelText);
		filteredObjectsButton.setSelection(filteredButtonSelected);

		Composite filterComposite = new Composite(composite, SWT.NONE);
		filterComposite.setLayout(new GridLayout(2, false));
		filterComposite.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		
		final Label filterLabel = new Label(filterComposite, SWT.NONE);
		filterLabel.setText(Messages.Batch_FileSystem_Rule_Filter + ":"); //$NON-NLS-1$
		filterLabel.setLayoutData(new GridData());
		filterLabel.setEnabled(filteredButtonSelected);
		
		filterText = new Text(filterComposite, SWT.BORDER);
		filterText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		filterText.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent event) {
				Text text = (Text)event.widget;
				getRule().setFilter(text.getText());
				setPageComplete(canFinish());
			}
		});
		filterText.setEnabled(filteredButtonSelected);
		filteredObjectsButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent event) {
				filterLabel.setEnabled(filteredObjectsButton.getSelection());
				filterText.setEnabled(filteredObjectsButton.getSelection());
				setPageComplete(canFinish());
			}
		});
		
		staticValueButton = new Button(composite, SWT.RADIO);
		staticValueButton.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		staticValueButton.setText(Messages.Batch_FileSystem_Rule_CommunityWizardPage_StaticButtonLabel);
		
		Composite staticComposite = new Composite(composite, SWT.NONE);
		staticComposite.setLayout(new GridLayout(2, false));
		staticComposite.setLayoutData(new GridData(GridData.FILL_BOTH));
		
		final Label communityNameLabel = new Label(staticComposite, SWT.NONE);
		communityNameLabel.setText(Messages.Batch_FileSystem_Rule_Community + ":"); //$NON-NLS-1$
		communityNameLabel.setLayoutData(new GridData());
		communityNameLabel.setEnabled(false);
		
		communityNameText = new Text(staticComposite, SWT.BORDER);
		communityNameText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		communityNameText.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent event) {
				Text text = (Text)event.widget;
				getCommunityRule().setCommunityName(text.getText());
				setPageComplete(canFinish());
			}
		});
		communityNameText.setEnabled(false);

		staticValueButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent event) {
				communityNameLabel.setEnabled(staticValueButton.getSelection());
				communityNameText.setEnabled(staticValueButton.getSelection());
				setPageComplete(canFinish());
			}
		});

		setControl(composite);
		setPageComplete(canFinish());
		PlatformUI.getWorkbench().getHelpSystem().setHelp(composite, HelpIds.RULEPAGE_COMMUNITY);
	}
	
	protected CommunityRule getCommunityRule() {
		return (CommunityRule)getRule();
	}
	
	public IRule getRule() {
		if (rule == null)
			rule = new CommunityRule();
		return rule;
	}
	
	private boolean canFinish() {
		if (filteredObjectsButton != null && filteredObjectsButton.getSelection())
			return filterText.getText().length() > 0;
		if (staticValueButton != null && staticValueButton.getSelection())
			return communityNameText.getText().length() > 0;
		return true;
	}
	
}
