/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem.ui;

import org.eclipse.core.runtime.Platform;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.*;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.graphics.FontData;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.*;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.views.properties.IPropertySource;
import org.eclipse.ui.views.properties.tabbed.AbstractPropertySection;
import org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetPage;

import com.ibm.ram.batch.ui.IBatchClientEditor;
import com.ibm.ram.internal.batch.filesystem.*;
import com.ibm.ram.internal.rich.core.PluginConstants;
import com.ibm.ram.internal.rich.ui.util.*;

/**
 * 
 * @author ebordeau
 * @since 7.1
 */
public class DataSourceSection extends AbstractPropertySection {
	
	private Label dirLabel;
	private Text dirText;
	private FileSystemDataSource dataSource;
	private IBatchClientEditor editor;

	private FocusListener focusListener = new FocusListener() {
		public void focusGained(FocusEvent event) {}
		public void focusLost(FocusEvent event) {
			commitChanges(event.widget);
		}
	};
	
	private KeyListener keyListener = new KeyAdapter() {
		public void keyPressed(KeyEvent event) {
			if (event.keyCode == SWT.CR)
				commitChanges(event.widget);
		}
	};
	
	private void commitChanges(Widget widget) {
		DataSourcePropertySource propSource = (DataSourcePropertySource)Platform.getAdapterManager().getAdapter(dataSource, IPropertySource.class);
		if (propSource != null) {
			propSource.setPropertyValue(DataSourcePropertySource.ROOT_DIR_ID, dirText.getText());
    		if (editor != null)
    			editor.refresh();
		}
	}

    public void createControls(Composite parent, TabbedPropertySheetPage page) {
		super.createControls(parent, page);
		
		final Composite composite = getWidgetFactory().createComposite(parent);
		composite.setLayout(new GridLayout(1, false));
		
		Composite topComp = new Composite(composite, SWT.FILL);
		final GridLayout gridLayout = new GridLayout(2, false);
		topComp.setLayout(gridLayout);
		topComp.setLayoutData(new GridData(SWT.FILL, SWT.TOP, true, false));

		Label icon = new Label(topComp, SWT.NONE);
		icon.setLayoutData(new GridData(SWT.LEFT, SWT.CENTER, false, false));
		icon.setImage(ImageUtil.FOLDER);
		
		dirLabel = new Label(topComp, SWT.WRAP);
		dirLabel.setLayoutData(new GridData(SWT.LEFT, SWT.CENTER, false, false));
		FontData fontData = new FontData(PluginConstants.EMPTY_STRING, 10, SWT.BOLD | SWT.BORDER);
		dirLabel.setFont(new Font(Display.getCurrent(), fontData));

		Composite bottomComp = new Composite(composite, SWT.FILL);
		final GridLayout bottomgridLayout = new GridLayout(2, false);
		bottomComp.setLayout(bottomgridLayout);
		bottomComp.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
		bottomComp.setBackground(HighContrastUtil.getWidgetBackground());

		Label nameLabel = new Label(bottomComp, SWT.WRAP);
		nameLabel.setLayoutData(new GridData(SWT.LEFT, SWT.CENTER, false, false));
		nameLabel.setText(Messages.Batch_FileSystem_RootDirectory);
		nameLabel.setBackground(HighContrastUtil.getWidgetBackground());
		nameLabel.setForeground(HighContrastUtil.getWidgetForeground());
		dirText = new Text(bottomComp, SWT.BORDER | SWT.SINGLE);
		dirText.setBackground(HighContrastUtil.getWidgetBackground());
		dirText.setForeground(HighContrastUtil.getWidgetForeground());
		dirText.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
	}
    
    public void aboutToBeShown() {
    	dirText.addFocusListener(focusListener);
    	dirText.addKeyListener(keyListener);
    }
    
    public void aboutToBeHidden() {
    	dirText.removeFocusListener(focusListener);
    	dirText.removeKeyListener(keyListener);
    }
    
    public void refresh() {
    	super.refresh();
    	if (dataSource != null) {
    		dirLabel.setText(dataSource.getRootPath());
    		dirLabel.pack();
    		dirText.setText(dataSource.getRootPath());
    	}
    }
	
	public void setInput(IWorkbenchPart part, ISelection selection) {
		super.setInput(part, selection);
		Object input = ((IStructuredSelection)selection).getFirstElement();
		if (input instanceof FileSystemDataSource)
			dataSource = (FileSystemDataSource)input;
		if (part instanceof IBatchClientEditor)
			editor = (IBatchClientEditor)part;
	}
	
}
