/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem.ui;

import org.eclipse.jface.viewers.*;
import org.eclipse.swt.SWT;
import org.eclipse.swt.dnd.*;
import org.eclipse.swt.widgets.DirectoryDialog;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.part.ResourceTransfer;
import org.eclipse.ui.views.navigator.LocalSelectionTransfer;

import com.ibm.ram.batch.ui.AbstractBatchUIContributor;
import com.ibm.ram.client.batch.BatchDataSource;
import com.ibm.ram.internal.batch.filesystem.FileSystemDataSource;
import com.ibm.ram.internal.rich.ui.util.Messages;

/**
 * 
 * @author ebordeau
 * @since 7.1
 */
public class FileSystemBatchUIContributor extends AbstractBatchUIContributor {
	
	private FileSystemBatchContentProvider contentProvider = new FileSystemBatchContentProvider();
	private FileSystemBatchLabelProvider labelProvider = new FileSystemBatchLabelProvider();
	private FileSystemDataSourceDropAdapter fDropTargetListner;
	private static Transfer[] SUPPORTED_TRANSFERS = new Transfer[]{
		ResourceTransfer.getInstance(), FileTransfer.getInstance(), LocalSelectionTransfer.getInstance()};


	public BatchDataSource createNewDataSource(Shell shell) {
		DirectoryDialog dialog = new DirectoryDialog(shell, SWT.NONE);
		dialog.setMessage(Messages.BatchUpdatePage_SELECT_ROOT_DIRECTORY);
		String dir = dialog.open();
		if (dir != null)
			return new FileSystemDataSource(dir);
		return null;
	}

	public ITreeContentProvider getContentProvider() {
		return contentProvider;
	}

	public ILabelProvider getLabelProvider() {
		return labelProvider;
	}

	/* (non-Javadoc)
	 * @see com.ibm.ram.batch.ui.AbstractBatchUIContributor#getDropTargetListener(org.eclipse.jface.viewers.StructuredViewer)
	 */
	public DropTargetListener getDropTargetListener(StructuredViewer viewer) {
		if(fDropTargetListner == null){
			fDropTargetListner = new FileSystemDataSourceDropAdapter(viewer);
		}
		return fDropTargetListner;
	}

	/* (non-Javadoc)
	 * @see com.ibm.ram.batch.ui.AbstractBatchUIContributor#getSupportedDropTransfers()
	 */
	public Transfer[] getSupportedDropTransfers() {
		return SUPPORTED_TRANSFERS;
	}

	
}
