/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem.ui;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.*;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.*;
import org.eclipse.ui.PlatformUI;

import com.ibm.ram.internal.batch.filesystem.*;
import com.ibm.ram.internal.rich.ui.util.HelpIds;
import com.ibm.ram.internal.rich.ui.util.Messages;

/**
 * Specify the metadata for an artifact rule.
 * 
 * @author ebordeau
 * @since 7.1
 */
public class NameRulePage extends RuleWizardPage {
	
	private NameRule rule;
	private Button filteredObjectsButton;
	private Button staticValueButton;
	private Text filterText;
	private Text nameText;
	
	/**
	 * @param pageName
	 * @param title
	 * @param titleImage
	 */
	public NameRulePage(IRuleContainer ruleContainer) {
		super(ruleContainer, NameRule.ID, Messages.Batch_FileSystem_Rule_NameWizardPage_Title, null);
		setMessage(Messages.Batch_FileSystem_Rule_WizardPage_Description);
	}

	public void createControl(Composite parent) {
		Composite composite = new Composite(parent, SWT.NONE);
		composite.setLayout(new GridLayout());
		composite.setLayoutData(new GridData(GridData.FILL_BOTH));
		
		filteredObjectsButton = new Button(composite, SWT.RADIO);
		filteredObjectsButton.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		filteredObjectsButton.setText(Messages.Batch_FileSystem_NameRuleWizardPage_FilteredFileButtonText);
		filteredObjectsButton.setSelection(true);
		
		Composite filterComposite = new Composite(composite, SWT.NONE);
		filterComposite.setLayout(new GridLayout(2, false));
		filterComposite.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		
		final Label filterLabel = new Label(filterComposite, SWT.NONE);
		filterLabel.setText(Messages.Batch_FileSystem_Rule_Filter + ":"); //$NON-NLS-1$
		filterLabel.setLayoutData(new GridData());
		filterLabel.setEnabled(true);
		
		filterText = new Text(filterComposite, SWT.BORDER);
		filterText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		filterText.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent event) {
				Text text = (Text)event.widget;
				getRule().setFilter(text.getText());
				setPageComplete(canFinish());
			}
		});
		filterText.setEnabled(true);
		filteredObjectsButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent event) {
				filterLabel.setEnabled(filteredObjectsButton.getSelection());
				filterText.setEnabled(filteredObjectsButton.getSelection());
				setPageComplete(canFinish());
			}
		});
		
		staticValueButton = new Button(composite, SWT.RADIO);
		staticValueButton.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		staticValueButton.setText(Messages.Batch_FileSystem_Rule_NameWizardPage_StaticButtonLabel);
		
		Composite staticComposite = new Composite(composite, SWT.NONE);
		staticComposite.setLayout(new GridLayout(2, false));
		staticComposite.setLayoutData(new GridData(GridData.FILL_BOTH));
		
		final Label nameLabel = new Label(staticComposite, SWT.NONE);
		nameLabel.setText(Messages.Batch_FileSystem_Rule_Name + ":"); //$NON-NLS-1$
		nameLabel.setLayoutData(new GridData());
		nameLabel.setEnabled(false);
		
		nameText = new Text(staticComposite, SWT.BORDER);
		nameText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		nameText.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent event) {
				Text text = (Text)event.widget;
				getNameRule().setName(text.getText());
				setPageComplete(canFinish());
			}
		});
		nameText.setEnabled(false);

		staticValueButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent event) {
				nameLabel.setEnabled(staticValueButton.getSelection());
				nameText.setEnabled(staticValueButton.getSelection());
				setPageComplete(canFinish());
			}
		});

		setControl(composite);
		setPageComplete(canFinish());
		PlatformUI.getWorkbench().getHelpSystem().setHelp(composite, HelpIds.RULEPAGE_NAME);
	}
	
	protected NameRule getNameRule() {
		return (NameRule)getRule();
	}
	
	public IRule getRule() {
		if (rule == null)
			rule = new NameRule();
		return rule;
	}
	
	private boolean canFinish() {
		if (filteredObjectsButton != null && filteredObjectsButton.getSelection())
			return filterText.getText().length() > 0;
		if (staticValueButton != null && staticValueButton.getSelection())
			return nameText.getText().length() > 0;
		return true;
	}
	
}
