/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem.ui;

import org.eclipse.core.runtime.Platform;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.*;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.graphics.FontData;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.*;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.views.properties.IPropertySource;
import org.eclipse.ui.views.properties.tabbed.AbstractPropertySection;
import org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetPage;

import com.ibm.ram.internal.batch.filesystem.*;
import com.ibm.ram.internal.rich.core.PluginConstants;
import com.ibm.ram.internal.rich.ui.util.HighContrastUtil;
import com.ibm.ram.internal.rich.ui.util.Messages;

/**
 * 
 * @author ebordeau
 * @since 7.1
 */
public class RuleSection extends AbstractPropertySection {
	
	private Label ruleIcon;
	private Label ruleLabel;
	private Text valueText;
	private Text filterText;
	private IRule rule;
	
	private FocusListener focusListener = new FocusListener() {
		public void focusGained(FocusEvent e) {}
		public void focusLost(FocusEvent e) {
			commitChanges(e.widget);
		}
	};
	
	private KeyListener keyListener = new KeyAdapter() {
		public void keyPressed(KeyEvent e) {
			if (e.keyCode == SWT.CR)
				commitChanges(e.widget);
		}
	};
	
	private void commitChanges(Widget widget) {
		RulePropertySource propSource = (RulePropertySource)Platform.getAdapterManager().getAdapter(rule, IPropertySource.class);
		if (propSource != null) {
			if (widget == valueText) {
				propSource.setPropertyValue(RulePropertySource.VALUE_ID, valueText.getText());
			} else if (widget == filterText) {
				propSource.setPropertyValue(RulePropertySource.FILTER_ID, filterText.getText());
			}
		}
	}

    public void createControls(Composite parent, TabbedPropertySheetPage page) {
		super.createControls(parent, page);
		
		final Composite composite = getWidgetFactory().createComposite(parent);
		composite.setLayout(new GridLayout(1, false));
		
		Composite topComp = new Composite(composite, SWT.FILL);
		final GridLayout gridLayout = new GridLayout(2, false);
		topComp.setLayout(gridLayout);
		topComp.setLayoutData(new GridData(SWT.FILL, SWT.TOP, true, false));

		ruleIcon = new Label(topComp, SWT.NONE);
		ruleIcon.setLayoutData(new GridData(SWT.LEFT, SWT.CENTER, false, false));
		
		ruleLabel = new Label(topComp, SWT.WRAP);
		ruleLabel.setLayoutData(new GridData(SWT.LEFT, SWT.CENTER, false, false));
		FontData fontData = new FontData(PluginConstants.EMPTY_STRING, 10, SWT.BOLD | SWT.BORDER);
		ruleLabel.setFont(new Font(Display.getCurrent(), fontData));

		Composite bottomComp = new Composite(composite, SWT.FILL);
		final GridLayout bottomgridLayout = new GridLayout(2, false);
		bottomComp.setLayout(bottomgridLayout);
		bottomComp.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
		bottomComp.setBackground(HighContrastUtil.getWidgetBackground());

		Label filterLabel = new Label(bottomComp, SWT.WRAP);
		filterLabel.setLayoutData(new GridData(SWT.LEFT, SWT.CENTER, false, false));
		filterLabel.setText(Messages.Batch_FileSystem_Rule_Filter);
		filterLabel.setBackground(HighContrastUtil.getWidgetBackground());
		filterLabel.setForeground(HighContrastUtil.getWidgetForeground());
		filterText = new Text(bottomComp, SWT.BORDER | SWT.SINGLE);
		filterText.setBackground(HighContrastUtil.getWidgetBackground());
		filterText.setForeground(HighContrastUtil.getWidgetForeground());
		filterText.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));

		Label valueLabel = new Label(bottomComp, SWT.WRAP);
		valueLabel.setLayoutData(new GridData(SWT.LEFT, SWT.CENTER, false, false));
		valueLabel.setText(Messages.Batch_FileSystem_Value);
		valueLabel.setBackground(HighContrastUtil.getWidgetBackground());
		valueLabel.setForeground(HighContrastUtil.getWidgetForeground());
		valueText = new Text(bottomComp, SWT.BORDER | SWT.SINGLE);
		valueText.setBackground(HighContrastUtil.getWidgetBackground());
		valueText.setForeground(HighContrastUtil.getWidgetForeground());
		valueText.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
	}
    
    public void aboutToBeShown() {
    	filterText.addFocusListener(focusListener);
    	filterText.addKeyListener(keyListener);
    	valueText.addFocusListener(focusListener);
    	valueText.addKeyListener(keyListener);
    }
    
    public void aboutToBeHidden() {
    	filterText.removeFocusListener(focusListener);
    	filterText.removeKeyListener(keyListener);
    	valueText.removeFocusListener(focusListener);
    	valueText.removeKeyListener(keyListener);
    }
    
    public void refresh() {
    	super.refresh();
    	if (rule != null) {
    		filterText.setText(rule.getFilter() == null ? "" : rule.getFilter()); //$NON-NLS-1$
    		valueText.setText(rule.getValue() == null ? "" : rule.getValue()); //$NON-NLS-1$
    		ruleLabel.setText(RuleUtil.getName(rule.getId()));
    		ruleIcon.setImage(RuleUtil.getImage(rule.getId()));
    		ruleLabel.pack();
    	}
    }
	
	public void setInput(IWorkbenchPart part, ISelection selection) {
		super.setInput(part, selection);
		Object input = ((IStructuredSelection)selection).getFirstElement();
		if (input instanceof IRule)
			rule = (IRule)input;
	}
	
}
