/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem.ui;

import org.eclipse.jface.viewers.*;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.*;
import org.eclipse.ui.PlatformUI;

import com.ibm.ram.internal.batch.filesystem.*;
import com.ibm.ram.internal.rich.ui.util.HelpIds;
import com.ibm.ram.internal.rich.ui.util.Messages;

/**
 * Wizard page to select the type of rule you'd like to create.
 * 
 * @author ebordeau
 * @since 7.1
 */
public class RuleTypePage extends WizardPage {
	
	private String selectedRule;
	private TableViewer viewer;
	private IRuleContainer ruleContainer;

	/**
	 * @param pageName
	 * @param title
	 * @param titleImage
	 */
	public RuleTypePage(IRuleContainer parent) {
		super("RuleTypePage", Messages.Batch_FileSystem_Rule_WizardTypePage_Title, null); //$NON-NLS-1$
		setMessage(Messages.Batch_FileSystem_Rule_WizardTypePage_Description);
		this.ruleContainer = parent;
	}

	public void createControl(Composite parent) {
		Composite composite = new Composite(parent, SWT.NONE);
		composite.setLayout(new GridLayout());
		composite.setLayoutData(new GridData(GridData.FILL_BOTH));

		Label label = new Label(composite, SWT.NONE);
		label.setText(Messages.Batch_FileSystem_Rule_RuleType + ":"); //$NON-NLS-1$
		label.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		
		Table table = new Table(composite, SWT.SINGLE | SWT.V_SCROLL | SWT.BORDER);
		viewer = new TableViewer(table);
		table.setLayoutData(new GridData(GridData.FILL_BOTH));
		viewer.setContentProvider(new IStructuredContentProvider() {
			public Object[] getElements(Object inputElement) {
				if (ruleContainer instanceof FileSystemDataSource) {
					return new String[] {
							AssetRule.ID, 
							CommunityRule.ID
						};
				} else if (ruleContainer instanceof AssetRule) {
					return new String[] {
							ArtifactRule.ID,
							AssetTypeRule.ID,
							AttributeRule.ID,
							CategoryRule.ID,
							CommunityRule.ID,
							DescriptionRule.ID,
							NameRule.ID,
							OwnerRule.ID,
							RelatedAssetRule.ID,
							ShortDescriptionRule.ID,
							VersionRule.ID
						};					
				} else if (ruleContainer instanceof CommunityRule) {
					return new String[] {
							AssetRule.ID
						};
				}
				return new Object[0];
			}
			public void dispose() {}
			public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {}
		});
		viewer.setLabelProvider(new LabelProvider() {
			public Image getImage(Object element) {
				if (element instanceof String)
					return RuleUtil.getImage((String)element);
				return super.getImage(element);
			}
			public String getText(Object element) {
				if (element instanceof String)
					return RuleUtil.getName((String)element);
				return super.getText(element);
			}
		});
		viewer.addDoubleClickListener(new IDoubleClickListener() {
			public void doubleClick(DoubleClickEvent event) {
				getContainer().showPage(getNextPage());
			}
		});
		viewer.addSelectionChangedListener(new ISelectionChangedListener() {
			public void selectionChanged(SelectionChangedEvent event) {
				IStructuredSelection selection = (IStructuredSelection)viewer.getSelection();
				selectedRule = (String)selection.getFirstElement();
				setPageComplete(selectedRule != null);
			}
		});
		viewer.setInput(this);
		
		setControl(composite);
		
		if (ruleContainer instanceof FileSystemDataSource)
			PlatformUI.getWorkbench().getHelpSystem().setHelp(composite, HelpIds.RULETYPEPAGE_DATASOURCE_PARENT);
		else if (ruleContainer instanceof AssetRule)
			PlatformUI.getWorkbench().getHelpSystem().setHelp(composite, HelpIds.RULETYPEPAGE_ASSET_PARENT);
		else if (ruleContainer instanceof CommunityRule)
			PlatformUI.getWorkbench().getHelpSystem().setHelp(composite, HelpIds.RULETYPEPAGE_COMMUNITY_PARENT);
	}
	
	public String getSelectedRuleId() {
		return selectedRule;
	}
	
	public boolean isPageComplete() {
		return getSelectedRuleId() != null;
	}

}
