/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem.ui;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.graphics.Point;

import com.ibm.ram.internal.batch.filesystem.*;
import com.ibm.ram.internal.rich.ui.util.*;

/**
 * @author ebordeau
 *
 */
public class RuleUtil {
	
	private static Map imageMap;
	private static Map imageDescriptorMap;
	
	private static void init() {
		imageMap = new HashMap();
		imageDescriptorMap = new HashMap();
		
		Image image = decorate(ImageUtil.ASSET_ICON, ImageUtil.OVERLAY_RULE);
		imageMap.put(AssetRule.ID, image);
		imageDescriptorMap.put(AssetRule.ID, ImageDescriptor.createFromImage(image));

		image = decorate(ImageUtil.COMMUNITIES, ImageUtil.OVERLAY_RULE);
		imageMap.put(CommunityRule.ID, image);
		imageDescriptorMap.put(CommunityRule.ID, ImageDescriptor.createFromImage(image));
		
		image = decorate(ImageUtil.FILE, ImageUtil.OVERLAY_RULE);
		imageMap.put(ArtifactRule.ID, image);
		imageDescriptorMap.put(ArtifactRule.ID, ImageDescriptor.createFromImage(image));
		
		image = decorate(ImageUtil.NAME_ICON, ImageUtil.OVERLAY_RULE);
		imageMap.put(NameRule.ID, image);
		imageDescriptorMap.put(NameRule.ID, ImageDescriptor.createFromImage(image));
		
		image = decorate(ImageUtil.DESCRIPTION_ICON, ImageUtil.OVERLAY_RULE);
		imageMap.put(DescriptionRule.ID, image);
		imageDescriptorMap.put(DescriptionRule.ID, ImageDescriptor.createFromImage(image));
		
		image = decorate(ImageUtil.SHORT_DESCRIPTION_ICON, ImageUtil.OVERLAY_RULE);
		imageMap.put(ShortDescriptionRule.ID, image);
		imageDescriptorMap.put(ShortDescriptionRule.ID, ImageDescriptor.createFromImage(image));
		
		image = decorate(ImageUtil.CUSTOM_ATTRIBUTES, ImageUtil.OVERLAY_RULE);
		imageMap.put(AttributeRule.ID, image);
		imageDescriptorMap.put(AttributeRule.ID, ImageDescriptor.createFromImage(image));
		
		image = decorate(ImageUtil.CATEGORIES, ImageUtil.OVERLAY_RULE);
		imageMap.put(CategoryRule.ID, image);
		imageDescriptorMap.put(CategoryRule.ID, ImageDescriptor.createFromImage(image));
		
		image = decorate(ImageUtil.ASSET_OWNER, ImageUtil.OVERLAY_RULE);
		imageMap.put(OwnerRule.ID, image);
		imageDescriptorMap.put(OwnerRule.ID, ImageDescriptor.createFromImage(image));
		
		image = decorate(ImageUtil.RELATIONSHIP_TYPES, ImageUtil.OVERLAY_RULE);
		imageMap.put(RelatedAssetRule.ID, image);
		imageDescriptorMap.put(RelatedAssetRule.ID, ImageDescriptor.createFromImage(image));
		
		image = decorate(ImageUtil.ASSET_TYPES, ImageUtil.OVERLAY_RULE);
		imageMap.put(AssetTypeRule.ID, image);
		imageDescriptorMap.put(AssetTypeRule.ID, ImageDescriptor.createFromImage(image));

		image = decorate(ImageUtil.VERSION_ACTION, ImageUtil.OVERLAY_RULE);
		imageMap.put(VersionRule.ID, image);
		imageDescriptorMap.put(VersionRule.ID, ImageDescriptor.createFromImage(image));
	}
	
	private static Image decorate(Image image, ImageDescriptor decoration) {
		ImageDescriptor[] overlays = new ImageDescriptor[] {null, null, null, null, null};
		overlays[DecoratorCompositeImageDescriptor.BOTTOM_LEFT] = decoration;
		DecoratorCompositeImageDescriptor overlay = new DecoratorCompositeImageDescriptor(image, overlays, new Point(16, 16));
		Image decoratedImage = overlay.createImage();
		imageMap.put(image.getImageData(), decoratedImage);
		return decoratedImage;
	}
	
	public static Image getImage(String id) {
		if (imageMap == null)
			init();
		Image image = (Image)imageMap.get(id);
		if (image == null)
			image = ImageUtil.RAM_CLIENT;
		return image;
	}
	
	public static String getName(String id) {
		if (AssetRule.ID.equals(id))
			return Messages.Batch_FileSystem_Rule_Asset;
		if (CommunityRule.ID.equals(id))
			return Messages.Batch_FileSystem_Rule_Community;
		if (ArtifactRule.ID.equals(id))
			return Messages.Batch_FileSystem_Rule_Artifact;
		if (AttributeRule.ID.equals(id))
			return Messages.Batch_FileSystem_Rule_Attribute;
		if (CategoryRule.ID.equals(id))
			return Messages.Batch_FileSystem_Rule_Category;
		if (OwnerRule.ID.equals(id))
			return Messages.Batch_FileSystem_Rule_Owner;
		if (RelatedAssetRule.ID.equals(id))
			return Messages.Batch_FileSystem_Rule_RelatedAsset;
		if (AssetTypeRule.ID.equals(id))
			return Messages.Batch_FileSystem_Rule_AssetType;
		if (DescriptionRule.ID.equals(id))
			return Messages.Batch_FileSystem_Rule_Description;
		if (NameRule.ID.equals(id))
			return Messages.Batch_FileSystem_Rule_Name;
		if (ShortDescriptionRule.ID.equals(id))
			return Messages.Batch_FileSystem_Rule_ShortDescription;
		if (VersionRule.ID.equals(id))
			return Messages.Batch_FileSystem_Rule_Version;
		return ""; //$NON-NLS-1$
	}

}
