/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
/*
 *  $RCSfile: $
 *  $Revision: $  $Date: $ 
 */
/**
 * 
 */
package com.ibm.ram.internal.batch.filesystem.ui;

import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.Wizard;

import com.ibm.ram.internal.batch.filesystem.IRuleContainer;
import com.ibm.ram.internal.rich.ui.util.Messages;

/**
 * A wizard to create a rule for creating  assets from file system objects.
 * 
 * @author ebordeau
 * @since 7.1
 */
public class RuleWizard extends Wizard {
	
	private IRuleContainer parent;
	private RuleTypePage ruleTypePage;
	private RuleWizardPage selectedRulePage;

	/**
	 * Create a new RuleWizard with the rule container that will 
	 * become the parent of the new rule.
	 */
	public RuleWizard(IRuleContainer parent) {
		this.parent = parent;
	}

	public void addPages() {
		setNeedsProgressMonitor(true);
		setWindowTitle(Messages.Batch_FileSystem_Rule_Wizard_Title);
		ruleTypePage = new RuleTypePage(parent);
		addPage(ruleTypePage);
		addPage(new AssetRulePage(parent));
		addPage(new CommunityRulePage(parent));
		addPage(new ArtifactRulePage(parent));
		addPage(new AssetTypeRulePage(parent));
		addPage(new AttributeRulePage(parent));
		addPage(new CategoryRulePage(parent));
		addPage(new DescriptionRulePage(parent));
		addPage(new NameRulePage(parent));
		addPage(new OwnerRulePage(parent));
		addPage(new RelatedAssetRulePage(parent));
		addPage(new ShortDescriptionRulePage(parent));
		addPage(new VersionRulePage(parent));
	}
	
    public boolean canFinish() {
        return ruleTypePage.isPageComplete() && (selectedRulePage != null && selectedRulePage.isPageComplete());
    }

	public IWizardPage getNextPage(IWizardPage page) {
		if (page instanceof RuleTypePage) {
			String ruleId = ((RuleTypePage)page).getSelectedRuleId();
			if (ruleId != null) {
				IWizardPage nextPage = getPage(ruleId);
				if (nextPage instanceof RuleWizardPage) {
					selectedRulePage = (RuleWizardPage)nextPage;
					return selectedRulePage;
				}
			}
		} else if (page instanceof RuleWizardPage) {
			return null;
		}
		return super.getNextPage(page);
	}
	
	public boolean performFinish() {
		if (selectedRulePage != null) {
			parent.add(selectedRulePage.getRule());
			return true;
		}
		return false;
	}

}
